@@ -23,8 +23,8 @@
 #include <new>
 
 #include <QApplication>
+#include <QIODevice>
 #include <QList>
-#include <QTextCodec>
 #include <QVariant>
 
 #include <KLocalizedString>
@@ -46,7 +46,6 @@
 Kwave::AsciiEncoder::AsciiEncoder()
     :Kwave::Encoder(), m_dst()
 {
-    m_dst.setCodec(QTextCodec::codecForName("UTF-8"));
     LOAD_MIME_TYPES
     REGISTER_COMPRESSION_TYPES
 }
@@ -170,7 +169,7 @@ bool Kwave::AsciiEncoder::encode(QWidget *widget,
     // end of file
     m_dst << "# EOF " << Qt::endl << Qt::endl;
 
-    m_dst.setDevice(Q_NULLPTR);
+    m_dst.setDevice(nullptr);
     dst.close();
 
     return result;
